==> zio-aws-proton_2.13-5.17.130.2-sources.jar: zio/aws/proton/model/EnvironmentTemplate.scala <==
package zio.aws.proton.model
import zio.aws.proton.model.primitives.{
  DisplayName,
  EnvironmentTemplateArn,
  FullTemplateVersionNumber,
  Timestamp,
  Arn,
  Description,
  ResourceName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class EnvironmentTemplate(
    arn: EnvironmentTemplateArn,
    createdAt: Timestamp,
    description: Option[Description] = None,
    displayName: Option[DisplayName] = None,
    encryptionKey: Option[Arn] = None,
    lastModifiedAt: Timestamp,
    name: ResourceName,
    provisioning: Option[zio.aws.proton.model.Provisioning] = None,
    recommendedVersion: Option[FullTemplateVersionNumber] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.proton.model.EnvironmentTemplate = {
    import EnvironmentTemplate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.proton.model.EnvironmentTemplate
      .builder()
      .arn(EnvironmentTemplateArn.unwrap(arn): java.lang.String)
      .createdAt(Timestamp.unwrap(createdAt): Instant)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        displayName.map(value => DisplayName.unwrap(value): java.lang.String)
      )(_.displayName)
      .optionallyWith(
        encryptionKey.map(value => Arn.unwrap(value): java.lang.String)
      )(_.encryptionKey)
      .lastModifiedAt(Timestamp.unwrap(lastModifiedAt): Instant)
      .name(ResourceName.unwrap(name): java.lang.String)
      .optionallyWith(provisioning.map(value => value.unwrap))(_.provisioning)
      .optionallyWith(
        recommendedVersion.map(value =>
          FullTemplateVersionNumber.unwrap(value): java.lang.String
        )
      )(_.recommendedVersion)
      .build()
  }
  def asReadOnly: zio.aws.proton.model.EnvironmentTemplate.ReadOnly =
    zio.aws.proton.model.EnvironmentTemplate.wrap(buildAwsValue())
}
object EnvironmentTemplate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.proton.model.EnvironmentTemplate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.proton.model.EnvironmentTemplate =
      zio.aws.proton.model.EnvironmentTemplate(
        arn,
        createdAt,
        description.map(value => value),
        displayName.map(value => value),
        encryptionKey.map(value => value),
        lastModifiedAt,
        name,
        provisioning.map(value => value),
        recommendedVersion.map(value => value)
      )
    def arn: EnvironmentTemplateArn
    def createdAt: Timestamp
    def description: Option[Description]
    def displayName: Option[DisplayName]
    def encryptionKey: Option[Arn]
    def lastModifiedAt: Timestamp
    def name: ResourceName
    def provisioning: Option[zio.aws.proton.model.Provisioning]
    def recommendedVersion: Option[FullTemplateVersionNumber]
    def getArn: ZIO[Any, Nothing, EnvironmentTemplateArn] = ZIO.succeed(arn)
    def getCreatedAt: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(createdAt)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getDisplayName: ZIO[Any, AwsError, DisplayName] =
      AwsError.unwrapOptionField("displayName", displayName)
    def getEncryptionKey: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("encryptionKey", encryptionKey)
    def getLastModifiedAt: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(lastModifiedAt)
    def getName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(name)
    def getProvisioning: ZIO[Any, AwsError, zio.aws.proton.model.Provisioning] =
      AwsError.unwrapOptionField("provisioning", provisioning)
    def getRecommendedVersion: ZIO[Any, AwsError, FullTemplateVersionNumber] =
      AwsError.unwrapOptionField("recommendedVersion", recommendedVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.proton.model.EnvironmentTemplate
  ) extends zio.aws.proton.model.EnvironmentTemplate.ReadOnly {
    override val arn: EnvironmentTemplateArn =
      zio.aws.proton.model.primitives.EnvironmentTemplateArn(impl.arn())
    override val createdAt: Timestamp =
      zio.aws.proton.model.primitives.Timestamp(impl.createdAt())
    override val description: Option[Description] = scala
      .Option(impl.description())
      .map(value => zio.aws.proton.model.primitives.Description(value))
    override val displayName: Option[DisplayName] = scala
      .Option(impl.displayName())
      .map(value => zio.aws.proton.model.primitives.DisplayName(value))
    override val encryptionKey: Option[Arn] = scala
      .Option(impl.encryptionKey())
      .map(value => zio.aws.proton.model.primitives.Arn(value))
    override val lastModifiedAt: Timestamp =
      zio.aws.proton.model.primitives.Timestamp(impl.lastModifiedAt())
    override val name: ResourceName =
      zio.aws.proton.model.primitives.ResourceName(impl.name())
    override val provisioning: Option[zio.aws.proton.model.Provisioning] = scala
      .Option(impl.provisioning())
      .map(value => zio.aws.proton.model.Provisioning.wrap(value))
    override val recommendedVersion: Option[FullTemplateVersionNumber] = scala
      .Option(impl.recommendedVersion())
      .map(value =>
        zio.aws.proton.model.primitives.FullTemplateVersionNumber(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.proton.model.EnvironmentTemplate
  ): zio.aws.proton.model.EnvironmentTemplate.ReadOnly = new Wrapper(impl)
}

==> zio-aws-proton_2.13-5.19.7.1-sources.jar: zio/aws/proton/model/EnvironmentTemplate.scala <==
package zio.aws.proton.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.proton.model.primitives.{
  DisplayName,
  EnvironmentTemplateArn,
  FullTemplateVersionNumber,
  Timestamp,
  Arn,
  Description,
  ResourceName
}
import scala.jdk.CollectionConverters._
final case class EnvironmentTemplate(
    arn: EnvironmentTemplateArn,
    createdAt: Timestamp,
    description: Optional[Description] = Optional.Absent,
    displayName: Optional[DisplayName] = Optional.Absent,
    encryptionKey: Optional[Arn] = Optional.Absent,
    lastModifiedAt: Timestamp,
    name: ResourceName,
    provisioning: Optional[zio.aws.proton.model.Provisioning] = Optional.Absent,
    recommendedVersion: Optional[FullTemplateVersionNumber] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.proton.model.EnvironmentTemplate = {
    import EnvironmentTemplate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.proton.model.EnvironmentTemplate
      .builder()
      .arn(EnvironmentTemplateArn.unwrap(arn): java.lang.String)
      .createdAt(Timestamp.unwrap(createdAt): Instant)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        displayName.map(value => DisplayName.unwrap(value): java.lang.String)
      )(_.displayName)
      .optionallyWith(
        encryptionKey.map(value => Arn.unwrap(value): java.lang.String)
      )(_.encryptionKey)
      .lastModifiedAt(Timestamp.unwrap(lastModifiedAt): Instant)
      .name(ResourceName.unwrap(name): java.lang.String)
      .optionallyWith(provisioning.map(value => value.unwrap))(_.provisioning)
      .optionallyWith(
        recommendedVersion.map(value =>
          FullTemplateVersionNumber.unwrap(value): java.lang.String
        )
      )(_.recommendedVersion)
      .build()
  }
  def asReadOnly: zio.aws.proton.model.EnvironmentTemplate.ReadOnly =
    zio.aws.proton.model.EnvironmentTemplate.wrap(buildAwsValue())
}
object EnvironmentTemplate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.proton.model.EnvironmentTemplate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.proton.model.EnvironmentTemplate =
      zio.aws.proton.model.EnvironmentTemplate(
        arn,
        createdAt,
        description.map(value => value),
        displayName.map(value => value),
        encryptionKey.map(value => value),
        lastModifiedAt,
        name,
        provisioning.map(value => value),
        recommendedVersion.map(value => value)
      )
    def arn: EnvironmentTemplateArn
    def createdAt: Timestamp
    def description: Optional[Description]
    def displayName: Optional[DisplayName]
    def encryptionKey: Optional[Arn]
    def lastModifiedAt: Timestamp
    def name: ResourceName
    def provisioning: Optional[zio.aws.proton.model.Provisioning]
    def recommendedVersion: Optional[FullTemplateVersionNumber]
    def getArn: ZIO[Any, Nothing, EnvironmentTemplateArn] = ZIO.succeed(arn)
    def getCreatedAt: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(createdAt)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getDisplayName: ZIO[Any, AwsError, DisplayName] =
      AwsError.unwrapOptionField("displayName", displayName)
    def getEncryptionKey: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("encryptionKey", encryptionKey)
    def getLastModifiedAt: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(lastModifiedAt)
    def getName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(name)
    def getProvisioning: ZIO[Any, AwsError, zio.aws.proton.model.Provisioning] =
      AwsError.unwrapOptionField("provisioning", provisioning)
    def getRecommendedVersion: ZIO[Any, AwsError, FullTemplateVersionNumber] =
      AwsError.unwrapOptionField("recommendedVersion", recommendedVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.proton.model.EnvironmentTemplate
  ) extends zio.aws.proton.model.EnvironmentTemplate.ReadOnly {
    override val arn: EnvironmentTemplateArn =
      zio.aws.proton.model.primitives.EnvironmentTemplateArn(impl.arn())
    override val createdAt: Timestamp =
      zio.aws.proton.model.primitives.Timestamp(impl.createdAt())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.proton.model.primitives.Description(value))
    override val displayName: Optional[DisplayName] = zio.aws.core.internal
      .optionalFromNullable(impl.displayName())
      .map(value => zio.aws.proton.model.primitives.DisplayName(value))
    override val encryptionKey: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.encryptionKey())
      .map(value => zio.aws.proton.model.primitives.Arn(value))
    override val lastModifiedAt: Timestamp =
      zio.aws.proton.model.primitives.Timestamp(impl.lastModifiedAt())
    override val name: ResourceName =
      zio.aws.proton.model.primitives.ResourceName(impl.name())
    override val provisioning: Optional[zio.aws.proton.model.Provisioning] =
      zio.aws.core.internal
        .optionalFromNullable(impl.provisioning())
        .map(value => zio.aws.proton.model.Provisioning.wrap(value))
    override val recommendedVersion: Optional[FullTemplateVersionNumber] =
      zio.aws.core.internal
        .optionalFromNullable(impl.recommendedVersion())
        .map(value =>
          zio.aws.proton.model.primitives.FullTemplateVersionNumber(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.proton.model.EnvironmentTemplate
  ): zio.aws.proton.model.EnvironmentTemplate.ReadOnly = new Wrapper(impl)
}
